import type { EventBridge } from 'aws-sdk';
import { FromSchema, JSONSchema } from 'json-schema-to-ts';
import type { EventBridgeEvent } from 'aws-lambda';
import { Bus } from './Bus';
export declare class Event<N extends string, S extends JSONSchema, P = FromSchema<S>> {
    private _name;
    private _source;
    private _bus;
    private _schema;
    private _validate;
    private _pattern;
    constructor({ name, source, bus, schema, }: {
        name: N;
        source: string;
        bus: Bus;
        schema: S;
    });
    get name(): N;
    get source(): string;
    get bus(): Bus;
    get schema(): S;
    get pattern(): {
        'detail-type': [N];
        source: string[];
    };
    get publishedEventSchema(): {
        type: 'object';
        properties: {
            source: {
                const: string;
            };
            'detail-type': {
                const: N;
            };
            detail: S;
        };
        required: ['source', 'detail-type', 'detail'];
    };
    publish(event: P): Promise<EventBridge.PutEventsResponse>;
}
declare type GenericEvent = Event<string, Record<string, unknown>, Record<string, unknown>>;
export declare type PublishedEvent<Event extends GenericEvent> = EventBridgeEvent<Event['name'], FromSchema<Event['schema']>>;
export {};
